==> haskell-hpack-0.18.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.18.1
id: hpack-0.18.1-DORLnoDCFbp9Gmr9axcGwr
key: hpack-0.18.1-DORLnoDCFbp9Gmr9axcGwr
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
exposed: True
indefinite: False
exposed-modules:
    Hpack Hpack.Config Hpack.Run Hpack.Yaml
hidden-modules: Hpack.FormattingHints Hpack.GenericsUtil
                Hpack.Haskell Hpack.Options Hpack.Render Hpack.Util Paths_hpack
abi: 0317b1520d9be67986352f7ea8775de8
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hpack-0.18.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hpack-0.18.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hpack-0.18.1
hs-libraries: HShpack-0.18.1-DORLnoDCFbp9Gmr9axcGwr
depends:
    base-4.10.0.0 base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    bytestring-0.10.8.2 deepseq-1.4.3.0 directory-1.3.0.2
    filepath-1.4.1.2 Glob-0.7.14-EWXJTNKCxct7qBMI2wP4uQ
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    yaml-0.8.23.3-5PA6FoFimacABkGYYUI5Gr
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             Glob-0.7.14-EWXJTNKCxct7qBMI2wP4uQ=11aaa389655065cfeb3ae5f8d6b7db28
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             yaml-0.8.23.3-5PA6FoFimacABkGYYUI5Gr=3efef415fb37938945c14dfc2fd6675d
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.18.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.18.1
id: hpack-0.18.1-3wiOt17PrgmC0K0g5pMeJT
key: hpack-0.18.1-3wiOt17PrgmC0K0g5pMeJT
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
exposed: True
indefinite: False
exposed-modules:
    Hpack Hpack.Config Hpack.Run Hpack.Yaml
hidden-modules: Hpack.FormattingHints Hpack.GenericsUtil
                Hpack.Haskell Hpack.Options Hpack.Render Hpack.Util Paths_hpack
abi: 277a54300272d611d054a63e5a68ea5b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hpack-0.18.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hpack-0.18.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hpack-0.18.1
hs-libraries: HShpack-0.18.1-3wiOt17PrgmC0K0g5pMeJT
depends:
    base-4.10.0.0 base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    bytestring-0.10.8.2 deepseq-1.4.3.0 directory-1.3.0.2
    filepath-1.4.1.2 Glob-0.7.14-EWXJTNKCxct7qBMI2wP4uQ
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    yaml-0.8.23.3-AZSsApCdj2T3XfDE7MlqSi
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             Glob-0.7.14-EWXJTNKCxct7qBMI2wP4uQ=11aaa389655065cfeb3ae5f8d6b7db28
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             yaml-0.8.23.3-AZSsApCdj2T3XfDE7MlqSi=7a6af61a5a6f451ce0540a63a6a62d32
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
